@@ -24,19 +24,17 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-           '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-           '-fstack-protector-strong -fno-plt -fno-semantic-interposition '
-           '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-           '-fstack-protector-strong -fno-plt -march=armv7-a -mfloat-abi=hard '
-           '-mfpu=vfpv3-d16 -O3 -pipe -fstack-protector-strong -fno-plt',
+           '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe -fno-plt '
+           '-fno-semantic-interposition -march=armv7-a -mfloat-abi=hard '
+           '-mfpu=vfpv3-d16 -O3 -pipe -fno-plt -march=armv7-a -mfloat-abi=hard '
+           '-mfpu=vfpv3-d16 -O3 -pipe -fno-plt',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 '
-                     '-pipe -fstack-protector-strong -fno-plt '
-                     '-fno-semantic-interposition',
+                     '-pipe -fno-plt -fno-semantic-interposition',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
@@ -52,16 +50,15 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
                 "'--with-tzpath=/usr/share/zoneinfo' 'CFLAGS=-march=armv7-a "
-                '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-                '-fstack-protector-strong -fno-plt '
+                '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe -fno-plt '
                 "-fno-semantic-interposition' "
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now "
                 "-fno-semantic-interposition' 'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python/src/Python-3.9.2/coverage.info',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.9.2/lcov-report',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.9.3/coverage.info',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.9.3/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2',
@@ -114,7 +111,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ASM_TYPES_H': 1,
  'HAVE_ATANH': 1,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
- 'HAVE_BLUETOOTH_BLUETOOTH_H': 1,
+ 'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
  'HAVE_BLUETOOTH_H': 0,
  'HAVE_BROKEN_MBSTOWCS': 0,
  'HAVE_BROKEN_NICE': 0,
@@ -648,13 +645,12 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
                              '-fwrapv -O3 -Wall -march=armv7-a '
                              '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt '
-                             '-fno-semantic-interposition -march=armv7-a '
+                             '-fno-plt -fno-semantic-interposition '
+                             '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 '
+                             '-O3 -pipe -fno-plt -march=armv7-a '
                              '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt -march=armv7-a '
-                             '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt -std=c99 '
-                             '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                             '-fno-plt -std=c99 -Wextra -Wno-unused-result '
+                             '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
@@ -663,11 +659,10 @@ build_time_vars = {'ABIFLAGS': '',
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
               '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-              '-fstack-protector-strong -fno-plt -fno-semantic-interposition '
+              '-fno-plt -fno-semantic-interposition -march=armv7-a '
+              '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe -fno-plt '
               '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-              '-fstack-protector-strong -fno-plt -march=armv7-a '
-              '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-              '-fstack-protector-strong -fno-plt',
+              '-fno-plt',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
@@ -675,14 +670,11 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
                    '-Wall -march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 '
-                   '-pipe -fstack-protector-strong -fno-plt '
-                   '-fno-semantic-interposition -march=armv7-a '
-                   '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-                   '-fstack-protector-strong -fno-plt -march=armv7-a '
-                   '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-                   '-fstack-protector-strong -fno-plt -std=c99 -Wextra '
-                   '-Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers '
+                   '-pipe -fno-plt -fno-semantic-interposition -march=armv7-a '
+                   '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe -fno-plt '
+                   '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
+                   '-fno-plt -std=c99 -Wextra -Wno-unused-result '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -D_FORTIFY_SOURCE=2 '
                    '-D_FORTIFY_SOURCE=2 -fPIC -DPy_BUILD_CORE',
@@ -699,14 +691,12 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
                         '-O3 -Wall -march=armv7-a -mfloat-abi=hard '
-                        '-mfpu=vfpv3-d16 -O3 -pipe -fstack-protector-strong '
-                        '-fno-plt -fno-semantic-interposition -march=armv7-a '
-                        '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-                        '-fstack-protector-strong -fno-plt -march=armv7-a '
-                        '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-                        '-fstack-protector-strong -fno-plt -std=c99 -Wextra '
-                        '-Wno-unused-result -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers '
+                        '-mfpu=vfpv3-d16 -O3 -pipe -fno-plt '
+                        '-fno-semantic-interposition -march=armv7-a '
+                        '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe -fno-plt '
+                        '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 '
+                        '-pipe -fno-plt -std=c99 -Wextra -Wno-unused-result '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2 '
@@ -719,7 +709,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.9.2',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.9.3',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
@@ -761,9 +751,9 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.9.2 ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.9.3 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.9.2 ./python '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.9.3 ./python '
                './Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -786,8 +776,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.9.2',
- 'abs_srcdir': '/build/python/src/Python-3.9.2',
+ 'abs_builddir': '/build/python/src/Python-3.9.3',
+ 'abs_srcdir': '/build/python/src/Python-3.9.3',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
